@@ -798,6 +798,7 @@ int signal_pixmap_width; /* from signalwindow.c 400 */
 int signal_fill_width; /* from signalwindow.c 401 */
 int old_signal_fill_width; /* from signalwindow.c 402 */
 int old_signal_fill_height; /* from signalwindow.c 403 */
+int right_align_active; /* from signalwindow.c */
 int fontheight; /* from signalwindow.c 404 */
 char dnd_state; /* from signalwindow.c 405 */
 unsigned int dnd_cursor_timer; /* from signalwindow.c */
@@ -1215,6 +1216,7 @@ char enable_vert_grid; /* from wavewindow.c 647 */
 char use_big_fonts; /* from wavewindow.c 648 */
 char use_nonprop_fonts; /* from wavewindow.c 649 */
 char do_resize_signals; /* from wavewindow.c 650 */
+char first_unsized_signals;
 int initial_signal_window_width;
 char constant_marker_update; /* from wavewindow.c 651 */
 char use_roundcaps; /* from wavewindow.c 652 */
